# Table of Contents

- [navigate-architecture-executive-dashboard](<./navigate-architecture-executive-dashboard.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Navigating the Architecture Executive Dashboard](<./Navigating-the-Architecture-Executive-Dashboard.md>)
  - [Dashboard Structure](<./Navigating-the-Architecture-Executive-Dashboard/Dashboard-Structure.md>)
  - [Example](<./Navigating-the-Architecture-Executive-Dashboard/Example.md>)
